==> jc-1.4.0.tar.gz: polyglot/lex/FloatLiteral.h <==
// public class polyglot.lex.FloatLiteral

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f598ef6a20cd42a9 polyglot_lex_FloatLiteral
// @dep_class 923d72acc1d3eef7 polyglot_lex_Literal
// @dep_class bcf65095391d700b polyglot_lex_NumericLiteral
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_NumericLiteral

#include "polyglot/lex/NumericLiteral.h"

#ifndef _JC_polyglot_lex_FloatLiteral_H_
#define _JC_polyglot_lex_FloatLiteral_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_FloatLiteral$sub_refs	_jc_polyglot_lex_FloatLiteral$sub_refs;
typedef struct _jc_polyglot_lex_FloatLiteral$sub_nonrefs	_jc_polyglot_lex_FloatLiteral$sub_nonrefs;
typedef struct _jc_polyglot_lex_FloatLiteral$refs	_jc_polyglot_lex_FloatLiteral$refs;
typedef struct _jc_polyglot_lex_FloatLiteral$nonrefs	_jc_polyglot_lex_FloatLiteral$nonrefs;
typedef struct _jc_polyglot_lex_FloatLiteral$object	_jc_polyglot_lex_FloatLiteral$object;

typedef const struct _jc_polyglot_lex_FloatLiteral$vmethods	_jc_polyglot_lex_FloatLiteral$vmethods;
typedef const struct _jc_polyglot_lex_FloatLiteral$vtable	_jc_polyglot_lex_FloatLiteral$vtable;
typedef const struct _jc_polyglot_lex_FloatLiteral$vtype	_jc_polyglot_lex_FloatLiteral$vtype;

// Constructors
extern void _jc_polyglot_lex_FloatLiteral$method$_init$8e7a26629d4120fe(_jc_env *, struct _jc_polyglot_lex_FloatLiteral$object *, struct _jc_polyglot_util_Position$object *, jfloat, jint);

// Virtual methods structure
struct _jc_polyglot_lex_FloatLiteral$vmethods {
};

// Vtable
struct _jc_polyglot_lex_FloatLiteral$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_Literal$vmethods	polyglot_lex_Literal;
	_jc_polyglot_lex_NumericLiteral$vmethods	polyglot_lex_NumericLiteral;
	_jc_polyglot_lex_FloatLiteral$vmethods	polyglot_lex_FloatLiteral;
};

// Vtype
struct _jc_polyglot_lex_FloatLiteral$vtype {
	_jc_type			type;
	_jc_polyglot_lex_FloatLiteral$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_FloatLiteral$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_lex_FloatLiteral$refs {
    _jc_polyglot_lex_FloatLiteral$sub_refs	polyglot_lex_FloatLiteral;
    _jc_polyglot_lex_NumericLiteral$sub_refs	polyglot_lex_NumericLiteral;
    _jc_polyglot_lex_Literal$sub_refs	polyglot_lex_Literal;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_FloatLiteral$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_FloatLiteral$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_Literal$sub_nonrefs	polyglot_lex_Literal;
    _jc_polyglot_lex_NumericLiteral$sub_nonrefs	polyglot_lex_NumericLiteral;
    _jc_polyglot_lex_FloatLiteral$sub_nonrefs	polyglot_lex_FloatLiteral;
};

// Object instance structure
struct _jc_polyglot_lex_FloatLiteral$object {
	_jc_polyglot_lex_FloatLiteral$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_FloatLiteral$vtype	*vtype;
	_jc_polyglot_lex_FloatLiteral$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_FloatLiteral$vtype _jc_polyglot_lex_FloatLiteral$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_FloatLiteral, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_FloatLiteral$class_object;

#endif	/* _JC_polyglot_lex_FloatLiteral_H_ */

==> jc-1.4.6.tar.gz: polyglot/lex/FloatLiteral.h <==
// public class polyglot.lex.FloatLiteral

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f598ef6a20cd42a9 polyglot_lex_FloatLiteral
// @dep_class 923d72acc1d3eef7 polyglot_lex_Literal
// @dep_class bcf65095391d700b polyglot_lex_NumericLiteral
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_NumericLiteral

#include "polyglot/lex/NumericLiteral.h"

#ifndef _JC_polyglot_lex_FloatLiteral_H_
#define _JC_polyglot_lex_FloatLiteral_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_FloatLiteral$sub_refs	_jc_polyglot_lex_FloatLiteral$sub_refs;
typedef struct _jc_polyglot_lex_FloatLiteral$sub_nonrefs	_jc_polyglot_lex_FloatLiteral$sub_nonrefs;
typedef struct _jc_polyglot_lex_FloatLiteral$refs	_jc_polyglot_lex_FloatLiteral$refs;
typedef struct _jc_polyglot_lex_FloatLiteral$nonrefs	_jc_polyglot_lex_FloatLiteral$nonrefs;
typedef struct _jc_polyglot_lex_FloatLiteral$object	_jc_polyglot_lex_FloatLiteral$object;

typedef const struct _jc_polyglot_lex_FloatLiteral$vmethods	_jc_polyglot_lex_FloatLiteral$vmethods;
typedef const struct _jc_polyglot_lex_FloatLiteral$vtable	_jc_polyglot_lex_FloatLiteral$vtable;
typedef const struct _jc_polyglot_lex_FloatLiteral$vtype	_jc_polyglot_lex_FloatLiteral$vtype;

// Constructors
extern void _jc_polyglot_lex_FloatLiteral$method$_init$8e7a26629d4120fe(_jc_env *, struct _jc_polyglot_lex_FloatLiteral$object *, struct _jc_polyglot_util_Position$object *, jfloat, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_lex_FloatLiteral$vmethods {
};

// Vtable
struct _jc_polyglot_lex_FloatLiteral$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_Literal$vmethods	polyglot_lex_Literal;
	_jc_polyglot_lex_NumericLiteral$vmethods	polyglot_lex_NumericLiteral;
	_jc_polyglot_lex_FloatLiteral$vmethods	polyglot_lex_FloatLiteral;
};

// Vtype
struct _jc_polyglot_lex_FloatLiteral$vtype {
	_jc_type			type;
	_jc_polyglot_lex_FloatLiteral$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_FloatLiteral$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_lex_FloatLiteral$refs {
    _jc_polyglot_lex_FloatLiteral$sub_refs	polyglot_lex_FloatLiteral;
    _jc_polyglot_lex_NumericLiteral$sub_refs	polyglot_lex_NumericLiteral;
    _jc_polyglot_lex_Literal$sub_refs	polyglot_lex_Literal;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_FloatLiteral$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_FloatLiteral$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_Literal$sub_nonrefs	polyglot_lex_Literal;
    _jc_polyglot_lex_NumericLiteral$sub_nonrefs	polyglot_lex_NumericLiteral;
    _jc_polyglot_lex_FloatLiteral$sub_nonrefs	polyglot_lex_FloatLiteral;
};

// Object instance structure
struct _jc_polyglot_lex_FloatLiteral$object {
	_jc_polyglot_lex_FloatLiteral$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_FloatLiteral$vtype	*vtype;
	_jc_polyglot_lex_FloatLiteral$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_FloatLiteral$vtype _jc_polyglot_lex_FloatLiteral$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_FloatLiteral, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_FloatLiteral$class_object;

#endif	/* _JC_polyglot_lex_FloatLiteral_H_ */
